{% extends "layout.html" %}
{% import "articles/_contributors.html" as contributor with context %}

{% block content %}
<h1>{{ _("Magic, Complexité et Machine de Turing") }}</h1>
{{ contributor.zombie33() }}
{% block section %} {% endblock %}
{% endblock %}

{% block script %}
<script>
	/*
	(function () {
		// DOM will be available here
		var elements = document.getElementsByClassName("card-block");
		[].forEach.call(elements, function (elt) {
			sC(elt.name, elt.id);
		});
	})();
	//*/
</script>
{% endblock %}

{% block scripts %}
<style>
	@font-face {
		font-family: titlefont;
		src: url(https://www.magic-ville.com/fr/fonts/bankgthd.ttf);
	}
	tr:hover{
		background-color: #fffdf5 !important;
	}
	.win_title {
		background:url(https://www.magic-ville.com/fr/graph/fond/win_title.jpg);
		border:1px black solid;
		border-radius:2px;
		padding:16px;
		margin:2px;
		font: 16px "titlefont" ;
		color: #ffffff;
		text-align: center;
	}
	.title16 {
		font: 16px "titlefont" ;
		color: #ffffff;
	}
	.W12 {
		font: 12px Verdana ;
		color: #ffffff;
	}
	.O14 {
		font: 14px Verdana ;
	}
	td > img {
		height: 16px;
	}
</style>
{% endblock %}
