{% extends "layout.html" %}
{% import "articles/_contributors.html" as contributor with context %}

{% block content %}
<h1>{{ _("L'Art de classifier les decks") }}</h1>
{{ contributor.zombie33() }}
{% block section %} {% endblock %}
{% endblock %}
